# mauve-client
No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.12
- Package version: 0.1.0
- Build package: io.swagger.codegen.v3.generators.python.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mauve_client 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mauve_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import mauve_client
from mauve_client.rest import ApiException
from pprint import pprint
# Configure HTTP basic authorization: basic
configuration = mauve_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = mauve_client.CategoriesApi(mauve_client.ApiClient(configuration))
accept = 'accept_example' # str | Accept Header
category_id = 56 # int | The unique identifier of a category
include = 'include_example' # str | Return additional data specified by a comma-separated list of values (current possible values: \"packaginginformation\", \"producer\", \"images\", \"prices\", \"prices_current\", \"pharmacy_wholesaler_availabilities\", \"categories\", \"abda_artikelstamm\", \"abdata_laiendaten\", \"abda_other_pack_sizes\", \"bundles\"\", \"translations\"). (optional)
shop_id = 56 # int | The unique identifier of a shop which is used to determine the shop and image urls (if not specified, the first available shop will be used) (optional)
offset = 56 # int | The (zero-based) offset of the first item in the collection to return (default: 0) (optional)
limit = 56 # int | The maximum number of entries to return. If the value exceeds the maximum, then the maximum value will be used. (default: 1000, maximum: 1000) (optional)

try:
    # Retrieve products listed in a specific category.
    api_response = api_instance.get_category_products_request_category_idproducts_get(accept, category_id, include=include, shop_id=shop_id, offset=offset, limit=limit)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CategoriesApi->get_category_products_request_category_idproducts_get: %s\n" % e)
# Configure HTTP basic authorization: basic
configuration = mauve_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = mauve_client.CategoriesApi(mauve_client.ApiClient(configuration))
accept = 'accept_example' # str | Accept Header
category_id = 56 # int | Numerical unique identifier of a category
include = 'include_example' # str | Return additional data specified by a comma-separated list of values (current possible values: \"translations\"). (optional)

try:
    # Retrieve a specific category.
    api_response = api_instance.get_category_request_category_id_get(accept, category_id, include=include)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CategoriesApi->get_category_request_category_id_get: %s\n" % e)
# Configure HTTP basic authorization: basic
configuration = mauve_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = mauve_client.CategoriesApi(mauve_client.ApiClient(configuration))
accept = 'accept_example' # str | Accept Header
category_id = 56 # int | Numerical unique identifier of a category
include = 'include_example' # str | Return additional data specified by a comma-separated list of values (current possible values: \"translations\"). (optional)

try:
    # Retrieve child categories of a specific category.
    api_response = api_instance.get_child_categories_request_category_idchildren_get(accept, category_id, include=include)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CategoriesApi->get_child_categories_request_category_idchildren_get: %s\n" % e)
# Configure HTTP basic authorization: basic
configuration = mauve_client.Configuration()
configuration.username = 'YOUR_USERNAME'
configuration.password = 'YOUR_PASSWORD'

# create an instance of the API class
api_instance = mauve_client.CategoriesApi(mauve_client.ApiClient(configuration))
accept = 'accept_example' # str | Accept Header
include = 'include_example' # str | Return additional data specified by a comma-separated list of values (current possible values: \"translations\"). (optional)

try:
    # Retrieve a list of categories.
    api_response = api_instance.search_categories_request_get(accept, include=include)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling CategoriesApi->search_categories_request_get: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.mauve.de/*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CategoriesApi* | [**get_category_products_request_category_idproducts_get**](docs/CategoriesApi.md#get_category_products_request_category_idproducts_get) | **GET** /categories/{CategoryId}/products | Retrieve products listed in a specific category.
*CategoriesApi* | [**get_category_request_category_id_get**](docs/CategoriesApi.md#get_category_request_category_id_get) | **GET** /categories/{CategoryId} | Retrieve a specific category.
*CategoriesApi* | [**get_child_categories_request_category_idchildren_get**](docs/CategoriesApi.md#get_child_categories_request_category_idchildren_get) | **GET** /categories/{CategoryId}/children | Retrieve child categories of a specific category.
*CategoriesApi* | [**search_categories_request_get**](docs/CategoriesApi.md#search_categories_request_get) | **GET** /categories/ | Retrieve a list of categories.
*CustomersApi* | [**create_customer_request_post**](docs/CustomersApi.md#create_customer_request_post) | **POST** /customers/ | Create a customer.
*CustomersApi* | [**delete_customer_request_customer_number_delete**](docs/CustomersApi.md#delete_customer_request_customer_number_delete) | **DELETE** /customers/{CustomerNumber} | Delete a specific customer.
*CustomersApi* | [**get_customer_request_customer_number_get**](docs/CustomersApi.md#get_customer_request_customer_number_get) | **GET** /customers/{CustomerNumber} | Retrieve a specific customer.
*CustomersApi* | [**search_customers_request_get**](docs/CustomersApi.md#search_customers_request_get) | **GET** /customers/ | Retrieve a list of customers.
*CustomersApi* | [**update_customer_request_customer_number_update**](docs/CustomersApi.md#update_customer_request_customer_number_update) | **PATCH** /customers/{CustomerNumber} | Update a customer.
*DocumentsApi* | [**create_document_line_request_document_numberdocument_lines_post**](docs/DocumentsApi.md#create_document_line_request_document_numberdocument_lines_post) | **POST** /documents/{DocumentNumber}/document_lines | Create a document line for a specific document
*DocumentsApi* | [**create_document_parcel_label_request_document_numberparcel_labels_post**](docs/DocumentsApi.md#create_document_parcel_label_request_document_numberparcel_labels_post) | **POST** /documents/{DocumentNumber}/parcel_labels | Create a parcel label for a specific document.
*DocumentsApi* | [**create_document_payment_request_document_numberpayments_post**](docs/DocumentsApi.md#create_document_payment_request_document_numberpayments_post) | **POST** /documents/{DocumentNumber}/payments | Create a payment for a specific document.
*DocumentsApi* | [**delete_document_line_request_document_numberdocument_lines_number_delete**](docs/DocumentsApi.md#delete_document_line_request_document_numberdocument_lines_number_delete) | **DELETE** /documents/{DocumentNumber}/document_lines/{Number} | Delete a document line for a specific document
*DocumentsApi* | [**download_document_pdf_request_document_numberpdf_get**](docs/DocumentsApi.md#download_document_pdf_request_document_numberpdf_get) | **GET** /documents/{DocumentNumber}/pdf | Retrieve a PDF of a specific document.
*DocumentsApi* | [**get_document_payment_request_document_numberpayments_get**](docs/DocumentsApi.md#get_document_payment_request_document_numberpayments_get) | **GET** /documents/{DocumentNumber}/payments | Retrieve the payments of a specific document.
*DocumentsApi* | [**get_document_request_document_number_get**](docs/DocumentsApi.md#get_document_request_document_number_get) | **GET** /documents/{DocumentNumber} | Retrieve a specific document.
*DocumentsApi* | [**search_document_types_request_get**](docs/DocumentsApi.md#search_document_types_request_get) | **GET** /document_types/ | Retrieve a list of document types.
*DocumentsApi* | [**search_documents_request_get**](docs/DocumentsApi.md#search_documents_request_get) | **GET** /documents/ | Retrieve a list of documents.
*DocumentsApi* | [**search_payment_methods_request_get**](docs/DocumentsApi.md#search_payment_methods_request_get) | **GET** /payment_methods/ | Retrieve a list of payment methods.
*DocumentsApi* | [**search_shipment_methods_request_get**](docs/DocumentsApi.md#search_shipment_methods_request_get) | **GET** /shipment_methods/ | Retrieve a list of shipment methods.
*DocumentsApi* | [**update_document_request_document_number_update**](docs/DocumentsApi.md#update_document_request_document_number_update) | **PATCH** /documents/{DocumentNumber} | Update a document. (currently in experimental state)
*DocumentsApi* | [**update_document_type_request_document_numberdocument_type_create**](docs/DocumentsApi.md#update_document_type_request_document_numberdocument_type_create) | **PUT** /documents/{DocumentNumber}/document_type | Update the document type of a specific document
*OrdersApi* | [**create_order_payment_request_order_numberpayments_post**](docs/OrdersApi.md#create_order_payment_request_order_numberpayments_post) | **POST** /orders/{OrderNumber}/payments | Create a payment for a specific order.
*OrdersApi* | [**create_order_prescription_image_request_order_numberprescription_images_post**](docs/OrdersApi.md#create_order_prescription_image_request_order_numberprescription_images_post) | **POST** /orders/{OrderNumber}/prescription_images | Create a prescription image for a specific order.
*OrdersApi* | [**create_order_request_post**](docs/OrdersApi.md#create_order_request_post) | **POST** /orders/ | Create an order.
*OrdersApi* | [**get_order_payment_request_order_numberpayments_get**](docs/OrdersApi.md#get_order_payment_request_order_numberpayments_get) | **GET** /orders/{OrderNumber}/payments | Retrieve the payments of a specific order.
*OrdersApi* | [**get_order_request_order_number_get**](docs/OrdersApi.md#get_order_request_order_number_get) | **GET** /orders/{OrderNumber} | Retrieve a specific order.
*OrdersApi* | [**get_order_status_request_order_numberstatus_get**](docs/OrdersApi.md#get_order_status_request_order_numberstatus_get) | **GET** /orders/{OrderNumber}/status | Retrieve the current status of a specific order.
*OthersApi* | [**get_ping_request_get**](docs/OthersApi.md#get_ping_request_get) | **GET** /ping | 
*PortalCategoriesApi* | [**get_portal_category_products_request_participantcategories_category_idproducts_get**](docs/PortalCategoriesApi.md#get_portal_category_products_request_participantcategories_category_idproducts_get) | **GET** /portal/{Participant}/categories/{CategoryId}/products | Retrieve products listed in a specific category of a specific portal participant.
*PortalDocumentsApi* | [**create_portal_document_payment_request_participantdocuments_document_numberpayments_post**](docs/PortalDocumentsApi.md#create_portal_document_payment_request_participantdocuments_document_numberpayments_post) | **POST** /portal/{Participant}/documents/{DocumentNumber}/payments | Create a payment for a specific document for a specific portal participant.
*PortalDocumentsApi* | [**get_portal_document_payment_request_participantdocuments_document_numberpayments_get**](docs/PortalDocumentsApi.md#get_portal_document_payment_request_participantdocuments_document_numberpayments_get) | **GET** /portal/{Participant}/documents/{DocumentNumber}/payments | Retrieve the payments of a specific document for a specific portal participant.
*PortalDocumentsApi* | [**get_portal_document_request_participantdocuments_document_number_get**](docs/PortalDocumentsApi.md#get_portal_document_request_participantdocuments_document_number_get) | **GET** /portal/{Participant}/documents/{DocumentNumber} | Retrieve a specific document for a specific portal participant.
*PortalDocumentsApi* | [**search_portal_document_request_participantdocuments_get**](docs/PortalDocumentsApi.md#search_portal_document_request_participantdocuments_get) | **GET** /portal/{Participant}/documents/ | Retrieve a list of documents for a specific portal participant.
*PortalDocumentsApi* | [**update_portal_document_type_request_participantdocuments_document_numberdocument_type_create**](docs/PortalDocumentsApi.md#update_portal_document_type_request_participantdocuments_document_numberdocument_type_create) | **PUT** /portal/{Participant}/documents/{DocumentNumber}/document_type | Update the document type of a specific document for a specific portal participant.
*PortalOrdersApi* | [**create_portal_order_payment_request_participantorders_order_numberpayments_post**](docs/PortalOrdersApi.md#create_portal_order_payment_request_participantorders_order_numberpayments_post) | **POST** /portal/{Participant}/orders/{OrderNumber}/payments | Create a payment for a specific order for a specific portal participant.
*PortalOrdersApi* | [**create_portal_order_prescription_image_request_participantorders_order_numberprescription_images_post**](docs/PortalOrdersApi.md#create_portal_order_prescription_image_request_participantorders_order_numberprescription_images_post) | **POST** /portal/{Participant}/orders/{OrderNumber}/prescription_images | Create a prescription image for a specific order for a specific portal participant.
*PortalOrdersApi* | [**create_portal_order_request_participantorders_post**](docs/PortalOrdersApi.md#create_portal_order_request_participantorders_post) | **POST** /portal/{Participant}/orders/ | Create a order for a specific portal participant.
*PortalOrdersApi* | [**get_portal_order_payment_request_participantorders_order_numberpayments_get**](docs/PortalOrdersApi.md#get_portal_order_payment_request_participantorders_order_numberpayments_get) | **GET** /portal/{Participant}/orders/{OrderNumber}/payments | Retrieve the payments of a specific order of a specific portal participant.
*PortalOrdersApi* | [**get_portal_order_request_participantorders_order_number_get**](docs/PortalOrdersApi.md#get_portal_order_request_participantorders_order_number_get) | **GET** /portal/{Participant}/orders/{OrderNumber} | Retrieve a specific order of a specific portal participant.
*PortalOrdersApi* | [**get_portal_order_status_request_participantorders_order_numberstatus_get**](docs/PortalOrdersApi.md#get_portal_order_status_request_participantorders_order_numberstatus_get) | **GET** /portal/{Participant}/orders/{OrderNumber}/status | Retrieve the current status of a specific order of a specific portal participant.
*PortalProductsApi* | [**delete_portal_prices_request_participantprices_sku_delete**](docs/PortalProductsApi.md#delete_portal_prices_request_participantprices_sku_delete) | **DELETE** /portal/{Participant}/prices/{Sku} | Delete all prices of a specific product of a specific portal participant.
*PortalProductsApi* | [**get_portal_availibity_request_participantavailabilities_sku_get**](docs/PortalProductsApi.md#get_portal_availibity_request_participantavailabilities_sku_get) | **GET** /portal/{Participant}/availabilities/{Sku} | Retrieve the availability information of a specific product of a specific portal participant.
*PortalProductsApi* | [**get_portal_price_fallback_request_participantprices_fallback_sku_get**](docs/PortalProductsApi.md#get_portal_price_fallback_request_participantprices_fallback_sku_get) | **GET** /portal/{Participant}/prices_fallback/{Sku} | Retrieve the fallback price of a specific product of a specific portal participant.
*PortalProductsApi* | [**get_portal_price_request_participantprices_sku_get**](docs/PortalProductsApi.md#get_portal_price_request_participantprices_sku_get) | **GET** /portal/{Participant}/prices/{Sku} | Retrieve the price of a specific product of a specific portal participant.
*PortalProductsApi* | [**get_portal_stock_request_participantstocks_sku_get**](docs/PortalProductsApi.md#get_portal_stock_request_participantstocks_sku_get) | **GET** /portal/{Participant}/stocks/{Sku} | Retrieve the stock of a specific product of a specific portal participant.
*PortalProductsApi* | [**search_portal_availabilities_request_participantavailabilities_get**](docs/PortalProductsApi.md#search_portal_availabilities_request_participantavailabilities_get) | **GET** /portal/{Participant}/availabilities/ | Retrieve a list of availability informations of a specific portal participant.
*PortalProductsApi* | [**search_portal_prices_fallback_request_participantprices_fallback_get**](docs/PortalProductsApi.md#search_portal_prices_fallback_request_participantprices_fallback_get) | **GET** /portal/{Participant}/prices_fallback/ | Retrieve a list of fallback prices of a specific portal participant.
*PortalProductsApi* | [**search_portal_prices_request_participantprices_get**](docs/PortalProductsApi.md#search_portal_prices_request_participantprices_get) | **GET** /portal/{Participant}/prices/ | Retrieve a list of prices of a specific portal participant.
*PortalProductsApi* | [**search_portal_stocks_request_participantstocks_get**](docs/PortalProductsApi.md#search_portal_stocks_request_participantstocks_get) | **GET** /portal/{Participant}/stocks/ | Retrieve a list of stocks of a specific portal participant.
*PortalProductsApi* | [**update_portal_prices_request_participantprices_create**](docs/PortalProductsApi.md#update_portal_prices_request_participantprices_create) | **PUT** /portal/{Participant}/prices/ | Update or create prices of a specific portal participant.
*PortalProductsApi* | [**update_portal_stocks_request_participantstocks_create**](docs/PortalProductsApi.md#update_portal_stocks_request_participantstocks_create) | **PUT** /portal/{Participant}/stocks/ | Update stocks of a specific portal participant.
*ProductsApi* | [**delete_prices_request_sku_delete**](docs/ProductsApi.md#delete_prices_request_sku_delete) | **DELETE** /prices/{Sku} | Delete prices of a specific product.
*ProductsApi* | [**get_availibity_request_sku_get**](docs/ProductsApi.md#get_availibity_request_sku_get) | **GET** /availabilities/{Sku} | Retrieve the availability information of a specific product.
*ProductsApi* | [**get_prices_request_sku_get**](docs/ProductsApi.md#get_prices_request_sku_get) | **GET** /prices/{Sku} | Retrieve the prices of a specific product.
*ProductsApi* | [**get_product_request_sku_get**](docs/ProductsApi.md#get_product_request_sku_get) | **GET** /products/{Sku} | Retrieve a specific product
*ProductsApi* | [**get_stock_request_sku_get**](docs/ProductsApi.md#get_stock_request_sku_get) | **GET** /stocks/{Sku} | Retrieve the stock and the external product stock of a specific product.
*ProductsApi* | [**search_availabilities_request_get**](docs/ProductsApi.md#search_availabilities_request_get) | **GET** /availabilities/ | Retrieve a list of availability informations.
*ProductsApi* | [**search_prices_request_get**](docs/ProductsApi.md#search_prices_request_get) | **GET** /prices | Retrieve product prices of a list of products.
*ProductsApi* | [**search_products_request_get**](docs/ProductsApi.md#search_products_request_get) | **GET** /products/ | Retrieve a list of products.
*ProductsApi* | [**search_stocks_request_get**](docs/ProductsApi.md#search_stocks_request_get) | **GET** /stocks | Retrieve the stock and external product stock of a list of products.
*ProductsApi* | [**update_prices_request_create**](docs/ProductsApi.md#update_prices_request_create) | **PUT** /prices/ | Update or create prices of a list of products.
*ProductsApi* | [**update_product_request_sku_update**](docs/ProductsApi.md#update_product_request_sku_update) | **PATCH** /products/{Sku} | Update a product.
*ProductsApi* | [**update_stocks_request_create**](docs/ProductsApi.md#update_stocks_request_create) | **PUT** /stocks/ | Updates the external stocks of a list of products.

## Documentation For Models

 - [AbdaArtikelstamm](docs/AbdaArtikelstamm.md)
 - [AbdaOtherPackSize](docs/AbdaOtherPackSize.md)
 - [AbdataLaiendaten](docs/AbdataLaiendaten.md)
 - [Availibity](docs/Availibity.md)
 - [BundleItem](docs/BundleItem.md)
 - [Category](docs/Category.md)
 - [CategoryTranslation](docs/CategoryTranslation.md)
 - [ContentUnit](docs/ContentUnit.md)
 - [CourierServiceSlot](docs/CourierServiceSlot.md)
 - [CreateCustomerRequest](docs/CreateCustomerRequest.md)
 - [CreateCustomerResponse](docs/CreateCustomerResponse.md)
 - [CreateDocumentLineRequest](docs/CreateDocumentLineRequest.md)
 - [CreateDocumentParcelLabelRequest](docs/CreateDocumentParcelLabelRequest.md)
 - [CreateDocumentPaymentRequest](docs/CreateDocumentPaymentRequest.md)
 - [CreateOrderPaymentRequest](docs/CreateOrderPaymentRequest.md)
 - [CreateOrderPaymentResponse](docs/CreateOrderPaymentResponse.md)
 - [CreateOrderPrescriptionImageRequest](docs/CreateOrderPrescriptionImageRequest.md)
 - [CreateOrderPrescriptionImageResponse](docs/CreateOrderPrescriptionImageResponse.md)
 - [CreateOrderRequest](docs/CreateOrderRequest.md)
 - [CreateOrderResponse](docs/CreateOrderResponse.md)
 - [CreatePortalDocumentPaymentRequest](docs/CreatePortalDocumentPaymentRequest.md)
 - [CreatePortalDocumentPaymentResponse](docs/CreatePortalDocumentPaymentResponse.md)
 - [CreatePortalOrderPaymentRequest](docs/CreatePortalOrderPaymentRequest.md)
 - [CreatePortalOrderPaymentResponse](docs/CreatePortalOrderPaymentResponse.md)
 - [CreatePortalOrderPrescriptionImageRequest](docs/CreatePortalOrderPrescriptionImageRequest.md)
 - [CreatePortalOrderPrescriptionImageResponse](docs/CreatePortalOrderPrescriptionImageResponse.md)
 - [CreatePortalOrderRequest](docs/CreatePortalOrderRequest.md)
 - [CreatePortalOrderResponse](docs/CreatePortalOrderResponse.md)
 - [Customer](docs/Customer.md)
 - [CustomerAddress](docs/CustomerAddress.md)
 - [CustomersBody](docs/CustomersBody.md)
 - [DeleteCustomerRequest](docs/DeleteCustomerRequest.md)
 - [DeleteDocumentLineRequest](docs/DeleteDocumentLineRequest.md)
 - [DeletePortalPricesRequest](docs/DeletePortalPricesRequest.md)
 - [DeletePricesRequest](docs/DeletePricesRequest.md)
 - [DictionaryStringString_](docs/DictionaryStringString_.md)
 - [Document](docs/Document.md)
 - [DocumentAddress](docs/DocumentAddress.md)
 - [DocumentLine](docs/DocumentLine.md)
 - [DocumentNumberDocumentLinesBody](docs/DocumentNumberDocumentLinesBody.md)
 - [DocumentNumberParcelLabelsBody](docs/DocumentNumberParcelLabelsBody.md)
 - [DocumentType](docs/DocumentType.md)
 - [DownloadDocumentPdfRequest](docs/DownloadDocumentPdfRequest.md)
 - [GetAvailibityRequest](docs/GetAvailibityRequest.md)
 - [GetAvailibityResponse](docs/GetAvailibityResponse.md)
 - [GetCategoryProductsRequest](docs/GetCategoryProductsRequest.md)
 - [GetCategoryProductsResponse](docs/GetCategoryProductsResponse.md)
 - [GetCategoryRequest](docs/GetCategoryRequest.md)
 - [GetCategoryResponse](docs/GetCategoryResponse.md)
 - [GetChildCategoriesRequest](docs/GetChildCategoriesRequest.md)
 - [GetChildCategoriesResponse](docs/GetChildCategoriesResponse.md)
 - [GetCustomerRequest](docs/GetCustomerRequest.md)
 - [GetCustomerResponse](docs/GetCustomerResponse.md)
 - [GetDocumentPaymentRequest](docs/GetDocumentPaymentRequest.md)
 - [GetDocumentPaymentResponse](docs/GetDocumentPaymentResponse.md)
 - [GetDocumentRequest](docs/GetDocumentRequest.md)
 - [GetDocumentResponse](docs/GetDocumentResponse.md)
 - [GetOrderPaymentRequest](docs/GetOrderPaymentRequest.md)
 - [GetOrderPaymentResponse](docs/GetOrderPaymentResponse.md)
 - [GetOrderRequest](docs/GetOrderRequest.md)
 - [GetOrderResponse](docs/GetOrderResponse.md)
 - [GetOrderStatusRequest](docs/GetOrderStatusRequest.md)
 - [GetOrderStatusResponse](docs/GetOrderStatusResponse.md)
 - [GetPingRequest](docs/GetPingRequest.md)
 - [GetPortalAvailibityRequest](docs/GetPortalAvailibityRequest.md)
 - [GetPortalAvailibityResponse](docs/GetPortalAvailibityResponse.md)
 - [GetPortalCategoryProductsRequest](docs/GetPortalCategoryProductsRequest.md)
 - [GetPortalCategoryProductsResponse](docs/GetPortalCategoryProductsResponse.md)
 - [GetPortalDocumentPaymentRequest](docs/GetPortalDocumentPaymentRequest.md)
 - [GetPortalDocumentPaymentResponse](docs/GetPortalDocumentPaymentResponse.md)
 - [GetPortalDocumentRequest](docs/GetPortalDocumentRequest.md)
 - [GetPortalDocumentResponse](docs/GetPortalDocumentResponse.md)
 - [GetPortalOrderPaymentRequest](docs/GetPortalOrderPaymentRequest.md)
 - [GetPortalOrderPaymentResponse](docs/GetPortalOrderPaymentResponse.md)
 - [GetPortalOrderRequest](docs/GetPortalOrderRequest.md)
 - [GetPortalOrderResponse](docs/GetPortalOrderResponse.md)
 - [GetPortalOrderStatusRequest](docs/GetPortalOrderStatusRequest.md)
 - [GetPortalOrderStatusResponse](docs/GetPortalOrderStatusResponse.md)
 - [GetPortalPriceFallbackRequest](docs/GetPortalPriceFallbackRequest.md)
 - [GetPortalPriceFallbackResponse](docs/GetPortalPriceFallbackResponse.md)
 - [GetPortalPriceRequest](docs/GetPortalPriceRequest.md)
 - [GetPortalPriceResponse](docs/GetPortalPriceResponse.md)
 - [GetPortalStockRequest](docs/GetPortalStockRequest.md)
 - [GetPortalStockResponse](docs/GetPortalStockResponse.md)
 - [GetPricesRequest](docs/GetPricesRequest.md)
 - [GetPricesResponse](docs/GetPricesResponse.md)
 - [GetProductRequest](docs/GetProductRequest.md)
 - [GetProductResponse](docs/GetProductResponse.md)
 - [GetStockRequest](docs/GetStockRequest.md)
 - [GetStockResponse](docs/GetStockResponse.md)
 - [Image](docs/Image.md)
 - [MeasuringUnit](docs/MeasuringUnit.md)
 - [Object](docs/Object.md)
 - [Order](docs/Order.md)
 - [OrderAddress](docs/OrderAddress.md)
 - [OrderLine](docs/OrderLine.md)
 - [OrderNumberPrescriptionImagesBody](docs/OrderNumberPrescriptionImagesBody.md)
 - [OrderNumberPrescriptionImagesBody1](docs/OrderNumberPrescriptionImagesBody1.md)
 - [OrderPayment](docs/OrderPayment.md)
 - [OrderStatus](docs/OrderStatus.md)
 - [PackagingInformation](docs/PackagingInformation.md)
 - [PackagingUnit](docs/PackagingUnit.md)
 - [ParcelLabel](docs/ParcelLabel.md)
 - [Payment](docs/Payment.md)
 - [PaymentMethod](docs/PaymentMethod.md)
 - [PharmacyWholesalerAvailability](docs/PharmacyWholesalerAvailability.md)
 - [PortalAvailibity](docs/PortalAvailibity.md)
 - [PortalPrice](docs/PortalPrice.md)
 - [PortalStock](docs/PortalStock.md)
 - [PrescriptionImage](docs/PrescriptionImage.md)
 - [Price](docs/Price.md)
 - [Producer](docs/Producer.md)
 - [Product](docs/Product.md)
 - [ProductTranslation](docs/ProductTranslation.md)
 - [ResponseError](docs/ResponseError.md)
 - [ResponseStatus](docs/ResponseStatus.md)
 - [SearchAvailabilitiesRequest](docs/SearchAvailabilitiesRequest.md)
 - [SearchAvailabilitiesResponse](docs/SearchAvailabilitiesResponse.md)
 - [SearchCategoriesRequest](docs/SearchCategoriesRequest.md)
 - [SearchCategoriesResponse](docs/SearchCategoriesResponse.md)
 - [SearchCustomersRequest](docs/SearchCustomersRequest.md)
 - [SearchCustomersResponse](docs/SearchCustomersResponse.md)
 - [SearchDocumentTypesRequest](docs/SearchDocumentTypesRequest.md)
 - [SearchDocumentTypesResponse](docs/SearchDocumentTypesResponse.md)
 - [SearchDocumentsRequest](docs/SearchDocumentsRequest.md)
 - [SearchDocumentsResponse](docs/SearchDocumentsResponse.md)
 - [SearchPaymentMethodsRequest](docs/SearchPaymentMethodsRequest.md)
 - [SearchPaymentMethodsResponse](docs/SearchPaymentMethodsResponse.md)
 - [SearchPortalAvailabilitiesRequest](docs/SearchPortalAvailabilitiesRequest.md)
 - [SearchPortalAvailabilitiesResponse](docs/SearchPortalAvailabilitiesResponse.md)
 - [SearchPortalDocumentRequest](docs/SearchPortalDocumentRequest.md)
 - [SearchPortalDocumentResponse](docs/SearchPortalDocumentResponse.md)
 - [SearchPortalPricesFallbackRequest](docs/SearchPortalPricesFallbackRequest.md)
 - [SearchPortalPricesFallbackResponse](docs/SearchPortalPricesFallbackResponse.md)
 - [SearchPortalPricesRequest](docs/SearchPortalPricesRequest.md)
 - [SearchPortalPricesResponse](docs/SearchPortalPricesResponse.md)
 - [SearchPortalStocksRequest](docs/SearchPortalStocksRequest.md)
 - [SearchPortalStocksResponse](docs/SearchPortalStocksResponse.md)
 - [SearchPricesRequest](docs/SearchPricesRequest.md)
 - [SearchPricesResponse](docs/SearchPricesResponse.md)
 - [SearchProductsRequest](docs/SearchProductsRequest.md)
 - [SearchProductsResponse](docs/SearchProductsResponse.md)
 - [SearchShipmentMethodsRequest](docs/SearchShipmentMethodsRequest.md)
 - [SearchShipmentMethodsResponse](docs/SearchShipmentMethodsResponse.md)
 - [SearchStocksRequest](docs/SearchStocksRequest.md)
 - [SearchStocksResponse](docs/SearchStocksResponse.md)
 - [ShipmentMethod](docs/ShipmentMethod.md)
 - [Stock](docs/Stock.md)
 - [UpdateCustomerRequest](docs/UpdateCustomerRequest.md)
 - [UpdateCustomerResponse](docs/UpdateCustomerResponse.md)
 - [UpdateDocumentRequest](docs/UpdateDocumentRequest.md)
 - [UpdateDocumentResponse](docs/UpdateDocumentResponse.md)
 - [UpdateDocumentTypeRequest](docs/UpdateDocumentTypeRequest.md)
 - [UpdateDocumentTypeResponse](docs/UpdateDocumentTypeResponse.md)
 - [UpdatePortalDocumentTypeRequest](docs/UpdatePortalDocumentTypeRequest.md)
 - [UpdatePortalDocumentTypeResponse](docs/UpdatePortalDocumentTypeResponse.md)
 - [UpdatePortalPricesRequest](docs/UpdatePortalPricesRequest.md)
 - [UpdatePortalStocksRequest](docs/UpdatePortalStocksRequest.md)
 - [UpdatePricesRequest](docs/UpdatePricesRequest.md)
 - [UpdateProductRequest](docs/UpdateProductRequest.md)
 - [UpdateProductResponse](docs/UpdateProductResponse.md)
 - [UpdateStocksRequest](docs/UpdateStocksRequest.md)

## Documentation For Authorization


## basic

- **Type**: HTTP basic authentication


## Author


